Admin Tasks
-----------

This section describes how to perform administration tasks for the
Object Generic Menu plugin.

Edit Menus
``````````

The custom object menus can be edited via the admin UI.

----

#.  Open the Peek Admin UI and navigate to the Object Generic Menu plugin.

#.  Click on the **Edit Menus** tab

#.  Enter the details.

#.  Click save.

----

The URL can take multiple placeholders with the format :code:`{key}`,
the URL placeholders can come from:

*   The display items key,

*   The json data attached to display item

*   Properties from DocDB for a document with the same ModelSet and Document key
    matching the ModelSet and display item key with the selected display item.


----

The user will see the new menu edit when next the menu is displayed to the user.